@@ -4,7 +4,7 @@ use warnings;
 
 use Exporter 'import';
 
-# $Id: Regexes.pm 6038 2010-06-09 08:04:50Z mullet $
+# $Id: Regexes.pm 6233 2010-06-16 06:04:40Z mullet $
 
 =head1 NAME
 
@@ -12,19 +12,21 @@ C<SVG::Rasterize::Regexes> - Commonly used regular expressions
 
 =head1 VERSION
 
-Version 0.003002
+Version 0.003004
 
 =cut
 
-our $VERSION = '0.003002';
+our $VERSION = '0.003004';
 
 our @EXPORT    = qw();
 our @EXPORT_OK = qw($WSP
 		    $CWSP
                     %RE_PACKAGE
+                    %RE_XML
+                    %RE_URI
                     %RE_NUMBER
                     %RE_LENGTH
-                    %RE_COLOR
+                    %RE_PAINT
                     %RE_TRANSFORM
                     %RE_VIEW_BOX
                     %RE_PATH
@@ -35,7 +37,7 @@ our %EXPORT_TAGS = (all           => [@EXPORT, @EXPORT_OK],
 		    whitespace    => [qw($WSP $CWSP)],
                     attributes    => [qw(%RE_NUMBER
                                          %RE_LENGTH
-                                         %RE_COLOR
+                                         %RE_PAINT
                                          %RE_TRANSFORM
                                          %RE_VIEW_BOX
                                          %RE_PATH
@@ -53,73 +55,131 @@ our %RE_PACKAGE = ();
 	qr/^$package_part(?:\:\:$package_part)*$/;
 }
 
+# XML stuff (the white space would probably also fit in here, but I
+# do not think that I will change that).
+our %RE_XML = ();
+$RE_XML{NAME_START_CHAR} = qr/[\:a-zA-Z\_]/;
+$RE_XML{NAME_CHAR}       = qr/[\:a-zA-Z\_\-\.0-9]/;
+$RE_XML{NAME}            = qr/$RE_XML{NAME_START_CHAR}$RE_XML{NAME_CHAR}*/;
+$RE_XML{p_NAME}          = qr/^$RE_XML{NAME}$/;
+
+# URI stuff
+# $RE_URI{FULL_URI} and its components except $RE_URI{FRAGMENT}
+# (which would be just .*) are taken from RFC2396.
+# Note that they are lax with respect to the characters occuring in
+# the components. These expressions can be used to split a URI into
+# its components, but before those are used they should be further
+# validated.
+our %RE_URI = ();
+$RE_URI{SCHEME}    = qr/[^\:\/\?\#]+/;
+$RE_URI{AUTHORITY} = qr/[^\/\?\#]*/;
+$RE_URI{PATH}      = qr/[^\?\#]*/;
+$RE_URI{QUERY}     = qr/[^\#]*/;
+$RE_URI{FRAGMENT}  = qr/(?:$RE_XML{NAME}|xpointer\(id\($RE_XML{NAME}\)\))/;
+$RE_URI{FULL_URI}  = qr/(?:$RE_URI{SCHEME}\:)?
+                        (?:\/\/$RE_URI{AUTHORITY})?
+                        (?:$RE_URI{PATH})
+                        (?:\?$RE_URI{QUERY})?
+                        (?:\#$RE_URI{FRAGMENT})?/x;
+$RE_URI{LOCAL_URI} = qr/\#$RE_URI{FRAGMENT}/;
+$RE_URI{URI}       = qr/(?:$RE_URI{FULL_URI}|$RE_URI{LOCAL_URI})/;
+$RE_URI{p_URI}     = qr/^$RE_URI{URI}$/;
+
 # numbers and lengths
 our %RE_NUMBER = ();
 our %RE_LENGTH = ();
-{
-    $RE_NUMBER{NNINTEGER}    = qr/\d+/;
-    $RE_NUMBER{p_NNINTEGER}  = qr/^$RE_NUMBER{NNINTEGER}$/;
-    $RE_NUMBER{INTEGER}      = qr/[\+\-]?$RE_NUMBER{NNINTEGER}/;
-    $RE_NUMBER{p_INTEGER}    = qr/^$RE_NUMBER{INTEGER}$/;
-    $RE_NUMBER{w_INTEGER}    = qr/^$WSP*$RE_NUMBER{INTEGER}$WSP*$/;
+$RE_NUMBER{NNINTEGER}    = qr/\d+/;
+$RE_NUMBER{p_NNINTEGER}  = qr/^$RE_NUMBER{NNINTEGER}$/;
+$RE_NUMBER{INTEGER}      = qr/[\+\-]?$RE_NUMBER{NNINTEGER}/;
+$RE_NUMBER{p_INTEGER}    = qr/^$RE_NUMBER{INTEGER}$/;
+$RE_NUMBER{w_INTEGER}    = qr/^$WSP*$RE_NUMBER{INTEGER}$WSP*$/;
 
-    $RE_NUMBER{NNFRACTION}   = qr/(?:\d*\.\d+|\d+\.)/;
-    $RE_NUMBER{FRACTION}     = qr/[\+\-]?$RE_NUMBER{NNFRACTION}/;
-    $RE_NUMBER{p_FRACTION}   = qr/^$RE_NUMBER{FRACTION}$/;
-    $RE_NUMBER{w_FRACTION}   = qr/^$WSP*$RE_NUMBER{FRACTION}$WSP*$/;
-    $RE_NUMBER{EXPONENT}     = qr/[eE][\+\-]?\d+/;
-    $RE_NUMBER{NNFLOAT}      = qr/(?:$RE_NUMBER{NNFRACTION}
-                                    $RE_NUMBER{EXPONENT}?
-                                   |$RE_NUMBER{NNINTEGER}
-                                    $RE_NUMBER{EXPONENT})/x;
-    $RE_NUMBER{FLOAT}        = qr/[\+\-]?$RE_NUMBER{NNFLOAT}/;
-    $RE_NUMBER{p_FLOAT}      = qr/^$RE_NUMBER{FLOAT}$/;
-    $RE_NUMBER{w_FLOAT}      = qr/^$WSP*$RE_NUMBER{FLOAT}$WSP*$/;
-    $RE_NUMBER{P_NNNUMBER}   = qr/(?:$RE_NUMBER{NNFRACTION}
-                                   |$RE_NUMBER{NNINTEGER})/x;
-    $RE_NUMBER{p_P_NNNUMBER} = qr/^$RE_NUMBER{P_NNNUMBER}$/;
-    $RE_NUMBER{w_P_NNNUMBER} = qr/^$WSP*$RE_NUMBER{P_NNNUMBER}$WSP*$/;
-    $RE_NUMBER{P_NUMBER}     = qr/[\+\-]?$RE_NUMBER{P_NNNUMBER}/;
-    $RE_NUMBER{p_P_NUMBER}   = qr/^$RE_NUMBER{P_NUMBER}$/;
-    $RE_NUMBER{w_P_NUMBER}   = qr/^$WSP*$RE_NUMBER{P_NUMBER}$WSP*$/;
-    $RE_NUMBER{A_NNNUMBER}   = qr/(?:$RE_NUMBER{NNFLOAT}
-                                 |$RE_NUMBER{NNINTEGER})/x;
-    $RE_NUMBER{p_A_NNNUMBER} = qr/^$RE_NUMBER{A_NNNUMBER}$/;
-    $RE_NUMBER{w_A_NNNUMBER} = qr/^$WSP*$RE_NUMBER{A_NNNUMBER}$WSP*$/;
-    $RE_NUMBER{A_NUMBER}     = qr/[\+\-]?$RE_NUMBER{A_NNNUMBER}/;
-    $RE_NUMBER{p_A_NUMBER}   = qr/^$RE_NUMBER{A_NUMBER}$/;
-    $RE_NUMBER{w_A_NUMBER}   = qr/^$WSP*$RE_NUMBER{A_NUMBER}$WSP*$/;
+$RE_NUMBER{NNFRACTION}   = qr/(?:\d*\.\d+|\d+\.)/;
+$RE_NUMBER{FRACTION}     = qr/[\+\-]?$RE_NUMBER{NNFRACTION}/;
+$RE_NUMBER{p_FRACTION}   = qr/^$RE_NUMBER{FRACTION}$/;
+$RE_NUMBER{w_FRACTION}   = qr/^$WSP*$RE_NUMBER{FRACTION}$WSP*$/;
+$RE_NUMBER{EXPONENT}     = qr/[eE][\+\-]?\d+/;
+$RE_NUMBER{NNFLOAT}      = qr/(?:$RE_NUMBER{NNFRACTION}
+                                $RE_NUMBER{EXPONENT}?
+                               |$RE_NUMBER{NNINTEGER}
+                                $RE_NUMBER{EXPONENT})/x;
+$RE_NUMBER{FLOAT}        = qr/[\+\-]?$RE_NUMBER{NNFLOAT}/;
+$RE_NUMBER{p_FLOAT}      = qr/^$RE_NUMBER{FLOAT}$/;
+$RE_NUMBER{w_FLOAT}      = qr/^$WSP*$RE_NUMBER{FLOAT}$WSP*$/;
+$RE_NUMBER{P_NNNUMBER}   = qr/(?:$RE_NUMBER{NNFRACTION}
+                               |$RE_NUMBER{NNINTEGER})/x;
+$RE_NUMBER{p_P_NNNUMBER} = qr/^$RE_NUMBER{P_NNNUMBER}$/;
+$RE_NUMBER{w_P_NNNUMBER} = qr/^$WSP*$RE_NUMBER{P_NNNUMBER}$WSP*$/;
+$RE_NUMBER{P_NUMBER}     = qr/[\+\-]?$RE_NUMBER{P_NNNUMBER}/;
+$RE_NUMBER{p_P_NUMBER}   = qr/^$RE_NUMBER{P_NUMBER}$/;
+$RE_NUMBER{w_P_NUMBER}   = qr/^$WSP*$RE_NUMBER{P_NUMBER}$WSP*$/;
+$RE_NUMBER{A_NNNUMBER}   = qr/(?:$RE_NUMBER{NNFLOAT}
+                             |$RE_NUMBER{NNINTEGER})/x;
+$RE_NUMBER{p_A_NNNUMBER} = qr/^$RE_NUMBER{A_NNNUMBER}$/;
+$RE_NUMBER{w_A_NNNUMBER} = qr/^$WSP*$RE_NUMBER{A_NNNUMBER}$WSP*$/;
+$RE_NUMBER{A_NUMBER}     = qr/[\+\-]?$RE_NUMBER{A_NNNUMBER}/;
+$RE_NUMBER{p_A_NUMBER}   = qr/^$RE_NUMBER{A_NUMBER}$/;
+$RE_NUMBER{w_A_NUMBER}   = qr/^$WSP*$RE_NUMBER{A_NUMBER}$WSP*$/;
 
-    $RE_LENGTH{UNIT}           = qr/(?:em|ex|px|pt|pc|cm|mm|in|\%)/;
-    $RE_LENGTH{ABS_UNIT}       = qr/(?:px|pt|pc|cm|mm|in)/;
-    $RE_LENGTH{P_LENGTH}       = qr/$RE_NUMBER{P_NUMBER}$RE_LENGTH{UNIT}?/;
-    $RE_LENGTH{p_P_LENGTH}     = qr/^$RE_LENGTH{P_LENGTH}$/;
-    $RE_LENGTH{w_P_LENGTH}     = qr/^$WSP*$RE_LENGTH{P_LENGTH}$WSP*$/;
-    $RE_LENGTH{ABS_P_LENGTH}   = qr/$RE_NUMBER{P_NUMBER}
-                                    $RE_LENGTH{ABS_UNIT}?/x;
-    $RE_LENGTH{p_ABS_P_LENGTH} = qr/^$RE_LENGTH{ABS_P_LENGTH}$/;
-    $RE_LENGTH{w_ABS_P_LENGTH} = qr/^$WSP*$RE_LENGTH{ABS_P_LENGTH}$WSP*$/;
-    $RE_LENGTH{A_LENGTH}       = qr/$RE_NUMBER{A_NUMBER}$RE_LENGTH{UNIT}?/;
-    $RE_LENGTH{p_A_LENGTH}     = qr/^$RE_LENGTH{A_LENGTH}$/;
-    $RE_LENGTH{w_A_LENGTH}     = qr/^$WSP*$RE_LENGTH{A_LENGTH}$WSP*$/;
-    $RE_LENGTH{ABS_A_LENGTH}   = qr/$RE_NUMBER{A_NUMBER}
-                                    $RE_LENGTH{ABS_UNIT}?/x;
-    $RE_LENGTH{p_ABS_A_LENGTH} = qr/^$RE_LENGTH{ABS_A_LENGTH}$/;
-    $RE_LENGTH{w_ABS_A_LENGTH} = qr/^$WSP*$RE_LENGTH{ABS_A_LENGTH}$WSP*$/;
+$RE_LENGTH{UNIT}           = qr/(?:em|ex|px|pt|pc|cm|mm|in|\%)/;
+$RE_LENGTH{ABS_UNIT}       = qr/(?:px|pt|pc|cm|mm|in)/;
+$RE_LENGTH{P_LENGTH}       = qr/$RE_NUMBER{P_NUMBER}$RE_LENGTH{UNIT}?/;
+$RE_LENGTH{p_P_LENGTH}     = qr/^$RE_LENGTH{P_LENGTH}$/;
+$RE_LENGTH{w_P_LENGTH}     = qr/^$WSP*$RE_LENGTH{P_LENGTH}$WSP*$/;
+$RE_LENGTH{ABS_P_LENGTH}   = qr/$RE_NUMBER{P_NUMBER}
+                                $RE_LENGTH{ABS_UNIT}?/x;
+$RE_LENGTH{p_ABS_P_LENGTH} = qr/^$RE_LENGTH{ABS_P_LENGTH}$/;
+$RE_LENGTH{w_ABS_P_LENGTH} = qr/^$WSP*$RE_LENGTH{ABS_P_LENGTH}$WSP*$/;
+$RE_LENGTH{A_LENGTH}       = qr/$RE_NUMBER{A_NUMBER}$RE_LENGTH{UNIT}?/;
+$RE_LENGTH{p_A_LENGTH}     = qr/^$RE_LENGTH{A_LENGTH}$/;
+$RE_LENGTH{w_A_LENGTH}     = qr/^$WSP*$RE_LENGTH{A_LENGTH}$WSP*$/;
+$RE_LENGTH{ABS_A_LENGTH}   = qr/$RE_NUMBER{A_NUMBER}
+                                $RE_LENGTH{ABS_UNIT}?/x;
+$RE_LENGTH{p_ABS_A_LENGTH} = qr/^$RE_LENGTH{ABS_A_LENGTH}$/;
+$RE_LENGTH{w_ABS_A_LENGTH} = qr/^$WSP*$RE_LENGTH{ABS_A_LENGTH}$WSP*$/;
 
-    $RE_LENGTH{p_A_LENGTHS}    = qr/^$RE_LENGTH{p_A_LENGTH}
-                                     (?:$CWSP$RE_LENGTH{p_A_LENGTH})*$/x;
-    $RE_LENGTH{LENGTHS_SPLIT}  = qr/$CWSP/;
-}
+$RE_LENGTH{p_A_LENGTHS}    = qr/^$RE_LENGTH{p_A_LENGTH}
+                                 (?:$CWSP$RE_LENGTH{p_A_LENGTH})*$/x;
+$RE_LENGTH{LENGTHS_SPLIT}  = qr/$CWSP/;
 
-# rgb colors
-our %RE_COLOR = ();
+# paint (fill and stroke)
+our %RE_PAINT = ();
 {
     my $rgbe = qr/[\+\-]?\d{1,3}\%?/;
 
-    $RE_COLOR{p_RGB} = qr/^rgb\($WSP*($rgbe)$WSP*\,
-                                $WSP*($rgbe)$WSP*\,
-                                $WSP*($rgbe)$WSP*\)$/x;
+    $RE_PAINT{RGB}      = qr/rgb\($WSP*$rgbe$WSP*\,
+                                  $WSP*$rgbe$WSP*\,
+                                  $WSP*$rgbe$WSP*\)/x;
+    $RE_PAINT{HEX}      = qr/\#[a-fA-F0-9]{3}(?:[a-fA-F0-9]{3})?/;
+    $RE_PAINT{NAME}     = qr/[a-z]+/;
+    $RE_PAINT{COLOR}    = qr/(?:$RE_PAINT{RGB}|
+                                $RE_PAINT{HEX}|
+                                $RE_PAINT{NAME})/x;
+    $RE_PAINT{p_COLOR}  = qr/^$RE_PAINT{COLOR}$/;
+    $RE_PAINT{ICC_SPEC} = qr/icc-color\($WSP*.*?
+                             (?:$WSP*\,$WSP*$RE_NUMBER{A_NUMBER})*
+                             $WSP*\)/x;
+    $RE_PAINT{DIRECT}   = qr/(?:none
+                              |currentColor
+                              |$RE_PAINT{COLOR}
+                               (?:$WSP+$RE_PAINT{ICC_SPEC})?
+                              |inherit)/x;
+    $RE_PAINT{p_DIRECT} = qr/^$RE_PAINT{DIRECT}$/;
+    $RE_PAINT{URI}      = qr/url\($RE_URI{URI}\)
+                                  (?:$WSP*$RE_PAINT{DIRECT})?/x;
+    $RE_PAINT{PAINT}    = qr/(?:$RE_PAINT{URI}|$RE_PAINT{DIRECT})/;
+    $RE_PAINT{p_PAINT}  = qr/^$RE_PAINT{PAINT}$/;
+
+    $RE_PAINT{RGB_SPLIT} = qr/^rgb\($WSP*($rgbe)$WSP*\,
+                                    $WSP*($rgbe)$WSP*\,
+                                    $WSP*($rgbe)$WSP*\)$/x;
+    $RE_PAINT{ICC_SPLIT} = qr/^($RE_PAINT{COLOR})$WSP+
+                               ($RE_PAINT{ICC_SPEC})$/x;
+    $RE_PAINT{HEX_SPLIT} = qr/^\#([a-fA-F0-9]{1,2})
+                                 ([a-fA-F0-9]{1,2})
+                                 ([a-fA-F0-9]{1,2})$/x;
+    $RE_PAINT{URI_SPLIT} = qr/^(url\($RE_URI{URI}\))$WSP*
+                               ($RE_PAINT{DIRECT})?$/x;
 }
 
 # attribute stuff
@@ -344,7 +404,7 @@ scientific notation within a C<style> attribute although strictly,
 this is forbidden by the specification. This may or may not change
 in the future.
 
-=head2 C<p> and C<w>
+=head2 C<p>, C<w>, and C<s>
 
 The regular expressions from this package might be used to build
 more complex expressions, but are also used to validate values which
@@ -353,6 +413,12 @@ expressions have C<p> (for pure) and C<w> (for white space)
 versions. If C<$RE> is an expression then C<$p_RE> will be
 C<qr/^$RE$/>, and C<$w_RE> will be C<qr/^$WSP*$RE$WSP*$/>.
 
+The validation expressions for path data and points lists of
+C<polyline> and C<polygon> elements also have a C<s> (for start)
+version. The background is that they are supposed to be rendered up
+to the erroneous part. If they match fully is only found out when
+they are split up into parts.
+
 =head1 LIST OF EXPRESSIONS
 
 Two expressions are exported directly as scalars, the other ones are
@@ -387,6 +453,13 @@ Camel book this is described, please point me to it. If this pattern
 is too strict for your favourite package name, you can change this
 variable.
 
+=item * %RE_URI
+
+Expressions to parse C<URI>s. Largely inspired by an expression
+given in L<RFC2396|http://www.ietf.org/rfc/rfc2396.txt>. These
+expressions can be used to recognize a C<URI> and split it into its
+pieces, but not for validation. It is enough for now, though.
+
 =item * %RE_NUMBER
 
 Contains expressions for integer and floating point numbers. The
@@ -402,12 +475,10 @@ that these expressions allow leading zeroes like '00030' or
 Lengths in C<SVG> consist of a number and optionally a length
 unit. See L<Units|SVG::Rasterize/Units> in C<SVG::Rasterize>.
 
-=item * %RE_COLOR
+=item * %RE_PAINT
 
-Currently only contains C<$RE_COLOR{p_RGB}> representing an C<SVG>
-color specification as something like C<rgb(0, 255, 31)>. It will
-probably be expanded when C<SVG::Rasterize> supports color profiles
-and such.
+Expressions for C<paint> attributes (see
+L<http://www.w3.org/TR/SVG11/painting.html#SpecifyingPaint>).
 
 =item * %RE_TRANSFORM
 
@@ -458,7 +529,7 @@ C<$WSP> and C<$CWSP>.
 
 =item * C<:attributes>
 
-C<%RE_NUMBER>, C<%RE_LENGTH>, C<%RE_COLOR>, C<%RE_TRANSFORM>,
+C<%RE_NUMBER>, C<%RE_LENGTH>, C<%RE_PAINT>, C<%RE_TRANSFORM>,
 C<%RE_VIEW_BOX>, C<%RE_PATH>, C<%RE_DASHARRAY>, C<%RE_POLY>.
 
 =back
