@@ -6,7 +6,7 @@ use Params::Validate qw(:types);
 
 use SVG::Rasterize::Regexes qw(:attributes);
 
-# $Id$
+# $Id: Extensibility.pm 6211 2010-06-15 04:21:13Z mullet $
 
 =head1 NAME
 
@@ -14,11 +14,11 @@ C<SVG::Rasterize::Specification::Extensibility> - specification for class Extens
 
 =head1 VERSION
 
-Version 0.003003
+Version 0.003004
 
 =cut
 
-our $VERSION = '0.003003';
+our $VERSION = '0.003004';
 
 our %CHILDREN = ('foreignObject' => {});
 
@@ -42,7 +42,7 @@ our %ATTR_VAL = ('foreignObject' => {'alignment-baseline'           => {'optiona
                                                                         'regex'    => qr/^(?:nonzero|evenodd|inherit)$/},
                                      'color'                        => {'optional' => 1,
                                                                         'type'     => SCALAR,
-                                                                        'regex'    => qr//},
+                                                                        'regex'    => $RE_PAINT{p_COLOR}},
                                      'color-interpolation'          => {'optional' => 1,
                                                                         'type'     => SCALAR,
                                                                         'regex'    => qr/^(?:auto|sRGB|linearRGB|inherit)$/},
@@ -75,7 +75,7 @@ our %ATTR_VAL = ('foreignObject' => {'alignment-baseline'           => {'optiona
                                                                         'regex'    => qr/^(?:false|true)$/},
                                      'fill'                         => {'optional' => 1,
                                                                         'type'     => SCALAR,
-                                                                        'regex'    => qr//},
+                                                                        'regex'    => $RE_PAINT{p_PAINT}},
                                      'fill-opacity'                 => {'optional' => 1,
                                                                         'type'     => SCALAR,
                                                                         'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
@@ -204,7 +204,7 @@ our %ATTR_VAL = ('foreignObject' => {'alignment-baseline'           => {'optiona
                                                                         'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
                                      'stroke'                       => {'optional' => 1,
                                                                         'type'     => SCALAR,
-                                                                        'regex'    => qr//},
+                                                                        'regex'    => $RE_PAINT{p_PAINT}},
                                      'stroke-dasharray'             => {'optional' => 1,
                                                                         'type'     => SCALAR,
                                                                         'regex'    => qr/$RE_DASHARRAY{p_DASHARRAY}|^inherit$|^none$/},
@@ -283,6 +283,7 @@ our %ATTR_HINTS = ('foreignObject' => {'color'        => {'color'  => 1},
                                        'width'        => {'length' => 1},
                                        'x'            => {'length' => 1},
                                        'y'            => {'length' => 1}});
+
 1;
 
 
