@@ -6,7 +6,7 @@ use Params::Validate qw(:types);
 
 use SVG::Rasterize::Regexes qw(:attributes);
 
-# $Id$
+# $Id: Font.pm 6211 2010-06-15 04:21:13Z mullet $
 
 =head1 NAME
 
@@ -14,11 +14,11 @@ C<SVG::Rasterize::Specification::Font> - specification for class Font
 
 =head1 VERSION
 
-Version 0.003003
+Version 0.003004
 
 =cut
 
-our $VERSION = '0.003003';
+our $VERSION = '0.003004';
 
 our %CHILDREN = ('font'      => {'desc'           => 1,
                                  'font-face'      => 1,
@@ -54,7 +54,7 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => qr/^(?:nonzero|evenodd|inherit)$/},
                                  'color'                        => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => $RE_PAINT{p_COLOR}},
                                  'color-interpolation'          => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/^(?:auto|sRGB|linearRGB|inherit)$/},
@@ -87,7 +87,7 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => qr/^(?:false|true)$/},
                                  'fill'                         => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => $RE_PAINT{p_PAINT}},
                                  'fill-opacity'                 => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
@@ -186,7 +186,7 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
                                  'stroke'                       => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => $RE_PAINT{p_PAINT}},
                                  'stroke-dasharray'             => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/$RE_DASHARRAY{p_DASHARRAY}|^inherit$|^none$/},
@@ -367,6 +367,7 @@ our %ATTR_HINTS = ('font'      => {'color'        => {'color'  => 1},
                                    'stroke'       => {'color'  => 1},
                                    'stroke-width' => {'length' => 1}},
                    'font-face' => {});
+
 1;
 
 
