@@ -6,7 +6,7 @@ use Params::Validate qw(:types);
 
 use SVG::Rasterize::Regexes qw(:attributes);
 
-# $Id$
+# $Id: Marker.pm 6211 2010-06-15 04:21:13Z mullet $
 
 =head1 NAME
 
@@ -14,11 +14,11 @@ C<SVG::Rasterize::Specification::Marker> - specification for class Marker
 
 =head1 VERSION
 
-Version 0.003003
+Version 0.003004
 
 =cut
 
-our $VERSION = '0.003003';
+our $VERSION = '0.003004';
 
 our %CHILDREN = ('marker' => {'a'                => 1,
                               'altGlyphDef'      => 1,
@@ -80,7 +80,7 @@ our %ATTR_VAL = ('marker' => {'alignment-baseline'           => {'optional' => 1
                                                                  'regex'    => qr/^(?:nonzero|evenodd|inherit)$/},
                               'color'                        => {'optional' => 1,
                                                                  'type'     => SCALAR,
-                                                                 'regex'    => qr//},
+                                                                 'regex'    => $RE_PAINT{p_COLOR}},
                               'color-interpolation'          => {'optional' => 1,
                                                                  'type'     => SCALAR,
                                                                  'regex'    => qr/^(?:auto|sRGB|linearRGB|inherit)$/},
@@ -113,7 +113,7 @@ our %ATTR_VAL = ('marker' => {'alignment-baseline'           => {'optional' => 1
                                                                  'regex'    => qr/^(?:false|true)$/},
                               'fill'                         => {'optional' => 1,
                                                                  'type'     => SCALAR,
-                                                                 'regex'    => qr//},
+                                                                 'regex'    => $RE_PAINT{p_PAINT}},
                               'fill-opacity'                 => {'optional' => 1,
                                                                  'type'     => SCALAR,
                                                                  'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
@@ -224,7 +224,7 @@ our %ATTR_VAL = ('marker' => {'alignment-baseline'           => {'optional' => 1
                                                                  'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
                               'stroke'                       => {'optional' => 1,
                                                                  'type'     => SCALAR,
-                                                                 'regex'    => qr//},
+                                                                 'regex'    => $RE_PAINT{p_PAINT}},
                               'stroke-dasharray'             => {'optional' => 1,
                                                                  'type'     => SCALAR,
                                                                  'regex'    => qr/$RE_DASHARRAY{p_DASHARRAY}|^inherit$|^none$/},
@@ -291,6 +291,7 @@ our %ATTR_HINTS = ('marker' => {'color'        => {'color'  => 1},
                                 'refY'         => {'length' => 1},
                                 'stroke'       => {'color'  => 1},
                                 'stroke-width' => {'length' => 1}});
+
 1;
 
 
