@@ -6,7 +6,7 @@ use Params::Validate qw(:types);
 
 use SVG::Rasterize::Regexes qw(:attributes);
 
-# $Id$
+# $Id: Text.pm 6211 2010-06-15 04:21:13Z mullet $
 
 =head1 NAME
 
@@ -14,11 +14,11 @@ C<SVG::Rasterize::Specification::Text> - specification for class Text
 
 =head1 VERSION
 
-Version 0.003003
+Version 0.003004
 
 =cut
 
-our $VERSION = '0.003003';
+our $VERSION = '0.003004';
 
 our %CHILDREN = ('altGlyphDef' => {'altGlyphItem'     => 1,
                                    'glyphRef'         => 1},
@@ -65,7 +65,7 @@ our %ATTR_VAL = ('altGlyphDef' => {'id'                           => {'optional'
                                                                       'regex'    => qr/^(?:nonzero|evenodd|inherit)$/},
                                    'color'                        => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => $RE_PAINT{p_COLOR}},
                                    'color-interpolation'          => {'optional' => 1,
                                                                       'type'     => SCALAR,
                                                                       'regex'    => qr/^(?:auto|sRGB|linearRGB|inherit)$/},
@@ -95,7 +95,7 @@ our %ATTR_VAL = ('altGlyphDef' => {'id'                           => {'optional'
                                                                       'regex'    => qr/^(?:false|true)$/},
                                    'fill'                         => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => $RE_PAINT{p_PAINT}},
                                    'fill-opacity'                 => {'optional' => 1,
                                                                       'type'     => SCALAR,
                                                                       'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
@@ -200,7 +200,7 @@ our %ATTR_VAL = ('altGlyphDef' => {'id'                           => {'optional'
                                                                       'regex'    => qr/^(?:auto|optimizeSpeed|crispEdges|geometricPrecision|inherit)$/},
                                    'stroke'                       => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => $RE_PAINT{p_PAINT}},
                                    'stroke-dasharray'             => {'optional' => 1,
                                                                       'type'     => SCALAR,
                                                                       'regex'    => qr/$RE_DASHARRAY{p_DASHARRAY}|^inherit$|^none$/},
@@ -277,6 +277,7 @@ our %ATTR_HINTS = ('altGlyphDef' => {},
                                      'stroke'       => {'color'  => 1},
                                      'stroke-width' => {'length' => 1},
                                      'textLength'   => {'length' => 1}});
+
 1;
 
 
